==> 0.0.18.tar.gz: lib/pages/user_posts.dart <==
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:feed_plugin/bloc/feed_cubit.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/widgets/loadingButtonIndicator.dart';
import 'package:feed_plugin/widgets/post.dart';

class UserPost extends StatefulWidget {
  const UserPost({
    Key key,
    @required this.userData,
    @required this.currentUser,
  }) : super(key: key);

  final UserModel userData;
  final UserModel currentUser;
  @override
  _UserPostState createState() => _UserPostState();
}

class _UserPostState extends State<UserPost> {
  FeedCubit feedCubit;
  var _scrollController = ScrollController();
  double defaultScreenWidth = 393.0;
  double defaultScreenHeight = 534.0;
  List<PostModel> postsList = [];
  int likeId;
  int dislikeId;
  int saveId;

  @override
  void initState() {
    _scrollController.addListener(_onScroll);
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitDown,
      DeviceOrientation.portraitUp,
    ]);
    feedCubit = BlocProvider.of<FeedCubit>(context);
    super.initState();
  }

  void _onScroll() {
    if (_scrollController.position.pixels ==
        _scrollController.position.maxScrollExtent) {
      getPosts();
    }
  }

  Future<List<PostModel>> getPosts() async {
    await getPostsReports();
    postsList = await feedCubit.feedRepository
        .fetchPostsByUserId(this.widget.userData.id);

    return postsList;
  }

  Future getPostsReports() async {
    List<ReportSubTypeModel> reportsSubTypeList =
        await feedCubit.feedRepository.fetchAllSubType();
    for (var i = 0; i < reportsSubTypeList.length; i++) {
      if (likeId == null || dislikeId == null || saveId == null) {
        if (reportsSubTypeList[i].type == "Like") {
          likeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Dislike") {
          dislikeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Save") {
          saveId = reportsSubTypeList[i].id;
        }
      } else {
        break;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    var agentName = (this.widget.userData.firstName).toString() +
        " " +
        (this.widget.userData.lastName).toString();
    return ScreenUtilInit(
      designSize: Size(defaultScreenWidth, defaultScreenHeight),
      allowFontScaling: false,
      builder: () =>
          //  LayoutBuilder(
          //   builder: (_, BoxConstraints constraints) {
          //     return MaterialApp(
          //       home:
          Scaffold(
        appBar: PreferredSize(
            preferredSize: Size.fromHeight(70.0),
            child: AppBar(
              backgroundColor: Color(0xFF083356),
              leading: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pop();
                  },
                  child: Padding(
                    padding: EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                    child: Icon(Icons.arrow_back, color: Colors.white),
                  )),
              title: Padding(
                padding: EdgeInsets.only(
                    left: ScreenUtil().setWidth(10),
                    top: ScreenUtil().setWidth(9)),
                child: Text(
                  agentName.toString() + " post",
                  style: TextStyle(color: Colors.white),
                ),
              ),
            )),
        body: FutureBuilder(
          future: getPosts(),
          builder: (context, projectSnap) {
            if (projectSnap.connectionState == ConnectionState.waiting ||
                projectSnap.connectionState == ConnectionState.none) {
              return Center(child: LoadingIndicatorDark());
            }
            return Stack(children: [
              RefreshIndicator(
                onRefresh: () {
                  return getPosts();
                },
                child: ListView.separated(
                  cacheExtent: 9999,
                  padding: EdgeInsets.all(ScreenUtil().setWidth(8)),
                  itemCount: postsList.length,
                  itemBuilder: (BuildContext context, int index) {
                    PostModel post = projectSnap.data[index];
                    return FeedPost(
                      postData: post,
                      likeId: likeId,
                      dislikeId: dislikeId,
                      saveId: saveId,
                      currentUser: this.widget.currentUser,
                      images: post.attachedUrl.split(","),
                      commentsLength: 0,
                    );
                  },
                  separatorBuilder: (BuildContext context, int index) =>
                      const Divider(),
                ),
              ),
            ]);
          },
        ),
      ),
      //     );
      //   },
      // ),
    );
  }
}

==> 0.0.19.tar.gz: lib/pages/user_posts.dart <==
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/widgets/loadingButtonIndicator.dart';
import 'package:feed_plugin/widgets/post.dart';

class UserPost extends StatefulWidget {
  const UserPost({
    Key key,
    @required this.userData,
    @required this.currentUser,
  }) : super(key: key);

  final UserModel userData;
  final UserModel currentUser;
  @override
  _UserPostState createState() => _UserPostState();
}

class _UserPostState extends State<UserPost> {
  HttpService httpService;
  FeedRepository feedRepository;
  var _scrollController = ScrollController();
  double defaultScreenWidth = 393.0;
  double defaultScreenHeight = 534.0;
  List<PostModel> postsList = [];
  int likeId;
  int dislikeId;
  int saveId;

  @override
  void initState() {
    _scrollController.addListener(_onScroll);
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitDown,
      DeviceOrientation.portraitUp,
    ]);
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    super.initState();
  }

  void _onScroll() {
    if (_scrollController.position.pixels ==
        _scrollController.position.maxScrollExtent) {
      getPosts();
    }
  }

  Future<List<PostModel>> getPosts() async {
    await getPostsReports();
    postsList =
        await feedRepository.fetchPostsByUserId(this.widget.userData.id);

    return postsList;
  }

  Future getPostsReports() async {
    List<ReportSubTypeModel> reportsSubTypeList =
        await feedRepository.fetchAllSubType();
    for (var i = 0; i < reportsSubTypeList.length; i++) {
      if (likeId == null || dislikeId == null || saveId == null) {
        if (reportsSubTypeList[i].type == "Like") {
          likeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Dislike") {
          dislikeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Save") {
          saveId = reportsSubTypeList[i].id;
        }
      } else {
        break;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    var agentName = (this.widget.userData.firstName).toString() +
        " " +
        (this.widget.userData.lastName).toString();
    return ScreenUtilInit(
      designSize: Size(defaultScreenWidth, defaultScreenHeight),
      allowFontScaling: false,
      builder: () =>
          //  LayoutBuilder(
          //   builder: (_, BoxConstraints constraints) {
          //     return MaterialApp(
          //       home:
          Scaffold(
        appBar: PreferredSize(
            preferredSize: Size.fromHeight(70.0),
            child: AppBar(
              backgroundColor: Color(0xFF083356),
              leading: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pop();
                  },
                  child: Padding(
                    padding: EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                    child: Icon(Icons.arrow_back, color: Colors.white),
                  )),
              title: Padding(
                padding: EdgeInsets.only(
                    left: ScreenUtil().setWidth(10),
                    top: ScreenUtil().setWidth(9)),
                child: Text(
                  agentName.toString() + " post",
                  style: TextStyle(color: Colors.white),
                ),
              ),
            )),
        body: FutureBuilder(
          future: getPosts(),
          builder: (context, projectSnap) {
            if (projectSnap.connectionState == ConnectionState.waiting ||
                projectSnap.connectionState == ConnectionState.none) {
              return Center(child: LoadingIndicatorDark());
            }
            return Stack(children: [
              RefreshIndicator(
                onRefresh: () {
                  return getPosts();
                },
                child: ListView.separated(
                  cacheExtent: 9999,
                  padding: EdgeInsets.all(ScreenUtil().setWidth(8)),
                  itemCount: postsList.length,
                  itemBuilder: (BuildContext context, int index) {
                    PostModel post = projectSnap.data[index];
                    return FeedPost(
                      postData: post,
                      likeId: likeId,
                      dislikeId: dislikeId,
                      saveId: saveId,
                      currentUser: this.widget.currentUser,
                      images: post.attachedUrl.split(","),
                      commentsLength: 0,
                    );
                  },
                  separatorBuilder: (BuildContext context, int index) =>
                      const Divider(),
                ),
              ),
            ]);
          },
        ),
      ),
      //     );
      //   },
      // ),
    );
  }
}
